until

Function until 

pub unsafe fn until(command: Command)
Queue and flush

Safety

Command must be valid according to the Daku spec. Failure to pass in valid Command struct may cause undefined behavior.